@@ -43,6 +43,21 @@ using namespace std;
 namespace ept {
 namespace apt {
 
+static time_t aptTimestamp()
+{
+    namespace wfs = wibble::sys::fs;
+
+    std::auto_ptr<struct stat> st = wfs::stat(
+        _config->FindFile( "Dir::Cache::pkgcache" ) );
+    time_t t1 = st.get() == NULL ? 0 : st->st_mtime;
+ 
+    std::auto_ptr<struct stat> st1 = wfs::stat(
+        _config->FindFile( "Dir::State::status" ) );
+    time_t t2 = st1.get() == NULL ? 0 : st1->st_mtime;
+ 
+    return t1 > t2 ? t1 : t2;
+}
+
 Exception::Exception(const std::string& context) throw ()
 	: Generic(context)
 {
@@ -79,17 +94,6 @@ static void aptInit ()
 		throw Exception("initialising apt system");
 }
 
-time_t aptTimestamp()
-{
-	std::auto_ptr<struct stat> st = wibble::sys::fs::stat(_config->FindFile( "Dir::Cache::pkgcache" ));
-	time_t t1 = st.get() == NULL ? 0 : st->st_mtime;
-
-	std::auto_ptr<struct stat> st1 = wibble::sys::fs::stat(_config->FindFile( "Dir::State::status" ));
-	time_t t2 = st1.get() == NULL ? 0 : st1->st_mtime;
-
-	return t1 > t2 ? t1 : t2;
-}
-
 struct AptImplementation
 {
 	pkgSourceList* m_list;
